@@ -77,12 +77,14 @@ def _parse_tfrecords_encoded(example, height, width, depth, keys,
     # Create a dictionary describing the features.
     feature_description = {
         keys[0]: tf.io.FixedLenFeature([], tf.string, default_value=""),
-        keys[1]: tf.io.FixedLenSequenceFeature([], tf.int64, True)
+        keys[1]: tf.io.FixedLenSequenceFeature([], tf.int64, True),
+        keys[2]: tf.io.FixedLenFeature([], tf.string, default_value="")
     }
 
     # TODO Single example vs. batch example
     example = tf.io.parse_single_example(example, feature_description)
     img_source = example[keys[0]]
+    img_filename = example[keys[2]]
     # Convert encoded jpeg bytes into tensors. TODO decode_image
     img_source = tf.image.decode_jpeg(img_source, channels=depth)
     img_source = tf.cast(img_source, tf.float32)
@@ -95,7 +97,7 @@ def _parse_tfrecords_encoded(example, height, width, depth, keys,
         label = tf.argmax(example[keys[1]], axis=0)
     else:
         label = example[keys[1]]
-    return img_source, label
+    return img_source, label, img_filename
 
 
 def _parse_tfrecords_raw(example, height, width, depth, keys):
